@@ -430,8 +430,12 @@ class PageTree(BaseModel, BaseTreeModel, UpdateInfoBaseModel, PermissionsBase):
         self._url_cache.clear()
         PageMeta._url_cache.clear()
 
-        # FIXME: We must clean the page cache, but this cleans it for every sites!
-        cache.clear()
+        # FIXME: We must only update the cache for the current SITE not for all sites.
+        try:
+            cache.smooth_update() # Save "last change" timestamp in django-tools SmoothCacheBackend
+        except AttributeError:
+            # No SmoothCacheBackend used -> clean the complete cache
+            cache.clear()
 
         return super(PageTree, self).save(*args, **kwargs)
 
