@@ -101,6 +101,9 @@ MIDDLEWARE_CLASSES = (
     # Save process informations. More info: https://github.com/jedie/django-processinfo
     'django_processinfo.middlewares.django_processinfo.ProcessInfoMiddleware',
 
+    # Set request.debug bool value:
+    'django_tools.debug.middlewares.SetRequestDebugMiddleware',
+
     # Block banned IP addresses and delete old pylucid.models.BanEntry items:
     'pylucid_project.middlewares.ip_ban.IPBanMiddleware',
 
@@ -120,13 +123,14 @@ MIDDLEWARE_CLASSES = (
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.middleware.locale.LocaleMiddleware',
 
-    # Own simple cache implementation similar to https://docs.djangoproject.com/en/1.3/topics/cache/#the-per-site-cache
-    'pylucid_project.middlewares.cache.PyLucidFetchFromCacheMiddleware',
-    'pylucid_project.middlewares.cache.PyLucidUpdateCacheMiddleware',
+    # https://github.com/jedie/django-tools/blob/master/django_tools/cache/README.creole
+    'django_tools.cache.site_cache_middleware.UpdateCacheMiddleware',
+    'django_tools.cache.site_cache_middleware.FetchFromCacheMiddleware',
 
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
+    'django.middleware.clickjacking.XFrameOptionsMiddleware',
 
     # Create request.user_settings at process_request() and save it on process_response():
     'dbpreferences.middleware.DBPreferencesMiddleware',
@@ -153,6 +157,10 @@ MIDDLEWARE_CLASSES = (
     "pylucid_project.middlewares.context_middlewares.PyLucidContextMiddlewares",
 )
 
+# For django_tools.cache.site_cache_middleware
+# https://github.com/jedie/django-tools/blob/master/django_tools/cache/README.creole
+CACHE_MIDDLEWARE_ANONYMOUS_ONLY = True # Don't use cache for authenticated users
+
 # Add stack information to every messages, but only if..
 #     ...settings.DEBUG == True
 # or
@@ -197,7 +205,6 @@ TEMPLATE_LOADERS = (
 # dictionary of items to be merged into the context.
 TEMPLATE_CONTEXT_PROCESSORS = (
     "django.contrib.auth.context_processors.auth",
-    "django.core.context_processors.debug", # Add 'debug' info in context
     "django.core.context_processors.i18n",
     "django.core.context_processors.request", # Add request object to context
     "django.core.context_processors.static", # Add STATIC_URL to context
@@ -288,10 +295,9 @@ except Exception, e:
 
 # http://www.djangoproject.com/documentation/authentication/#other-authentication-sources
 AUTHENTICATION_BACKENDS = (
-    "pylucid.system.auth_backends.SiteAuthBackend",
-    "pylucid.system.auth_backends.SiteSHALoginAuthBackend",
+    "pylucid_project.pylucid_plugins.auth.auth_backends.SiteAuthBackend",
+    "pylucid_project.pylucid_plugins.auth.auth_backends.SiteSHALoginAuthBackend",
 #    "django.contrib.auth.backends.ModelBackend",
-#    "pylucid_project.pylucid_plugins.auth.auth_backend.JS_SHA_Backend",
 )
 # http://docs.djangoproject.com/en/dev/topics/auth/#storing-additional-information-about-users
 AUTH_PROFILE_MODULE = "pylucid.UserProfile"
@@ -381,28 +387,30 @@ else:
 LOCAL_SYNC_CACHE_BACKEND = "local_sync_cache"
 
 #_______________________________________________________________________________
-
 # Set the Django cache system.
+
+CACHE_MIDDLEWARE_SECONDS = 3600 # 1h
+
 # The LocMemCache isn't memory-efficient. Should be changed in local_settings.py !
+_BACKEND = "django_tools.cache.smooth_cache_backends.SmoothLocMemCache"
 CACHES = {
     'default': {
-        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
+        'BACKEND': _BACKEND,
         'LOCATION': 'PyLucid-default-cache',
+        'TIMEOUT': CACHE_MIDDLEWARE_SECONDS,
     },
     'dbtemplates': { # http://django-dbtemplates.readthedocs.org/en/latest/advanced/#caching
-        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
+        'BACKEND': _BACKEND,
         'LOCATION': 'PyLucid-dbtemplates-cache',
+        'TIMEOUT': CACHE_MIDDLEWARE_SECONDS,
     },
     LOCAL_SYNC_CACHE_BACKEND: { # https://github.com/jedie/django-tools/blob/master/django_tools/local_sync_cache/local_sync_cache.py
-        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
+        'BACKEND': _BACKEND,
         'LOCATION': 'PyLucid-local_sync-cache',
+        'TIMEOUT': CACHE_MIDDLEWARE_SECONDS,
     },
 }
 
-# Set default cache timeout (in seconds) to 2 Days (used in own PyLucid cache middleware, too) 
-CACHE_MIDDLEWARE_SECONDS = 60 * 60 * 48
-
-
 #_______________________________________________________________________________
 
 # unittest running?
